# 2nd version of "barGraphsReductionsRadiativeEffects.py"
#
# This one will include the BNU model, take out the version without the kernel stuff that was in my AGU poster, 
# and add a version based on instantaneous CO2 forcing instead of effective CO2 forcing. 
# Also add a bar for stratospheric adjustment. 
#
# Rick Russotto
# Started 2018-02-20


import numpy as np
from collections import OrderedDict
import matplotlib.pyplot as plt
import copy

modelNames = OrderedDict()
modelNames['bn'] = 'BNU-ESM'
modelNames['ca'] = 'CanESM-2'
modelNames['cc'] = 'CCSM4'
modelNames['ce'] = 'CESM-CAM5.1-FV'
modelNames['cs'] = 'CSIRO-Mk3L-1-2'
modelNames['ec'] = 'EC-EARTH-DMI'
modelNames['gi'] = 'GISS-E2-R'
modelNames['hc'] = 'HadCM3'
modelNames['hg'] = 'HadGEM2-ES'
modelNames['ip'] = 'IPSL-CM5A-LR'
modelNames['mi'] = 'MIROC-ESM'
modelNames['mp'] = 'MPI-ESM-LR'
modelNames['no'] = 'NorESM1-M'
modelNames['mm'] = 'Multi-Model Mean'    



#Variables like solar reduction read in from published tables 

#Solar constant reductions (percent)
#(Source: Kravitz et al. 2013 G1 overview paper, except for CSIRO which I calculated myself)
reductions_dict = dict()
reductions_dict['bn'] = 4.4 #For r3i1p1--personal communication from Duoying Ji
reductions_dict['ca'] = 4.0
reductions_dict['cc'] = 4.1
reductions_dict['ce'] = 4.7
reductions_dict['cs'] = 3.2
reductions_dict['ec'] = 4.3 
reductions_dict['gi'] = 4.5 
reductions_dict['hc'] = 4.1 
reductions_dict['hg'] = 3.9 
reductions_dict['ip'] = 3.5 
reductions_dict['mi'] = 5.0 
reductions_dict['mp'] = 4.7 
reductions_dict['no'] = 4.0
                    
#Additional calculation: plot predicted based on forcing/albedo formula vs. actual solar reduction
#Effective radiative forcing for a doubling of CO2, from Sherwood et al., Nature, 2014 (W m^-2)
forcingsS14_dict = dict()
forcingsS14_dict['bn'] = 3.78
forcingsS14_dict['ca'] = 3.85
forcingsS14_dict['cc'] = 3.70
forcingsS14_dict['gi'] = 3.77
forcingsS14_dict['hg'] = 2.95
forcingsS14_dict['ip'] = 3.12
forcingsS14_dict['mi'] = 4.27
forcingsS14_dict['mp'] = 4.15
forcingsS14_dict['no'] = 3.21               

#Planetary albedo (%) (piContol), from Kravitz et al. 2013 (K13) (note planetary albedo is different in abrupt4xCO2, not sure which one modelers used)
albedosK13_dict = dict()
albedosK13_dict['bn'] = 29.8
albedosK13_dict['ca'] = 29.5
albedosK13_dict['cc'] = 28.7
albedosK13_dict['ce'] = 29.6
albedosK13_dict['gi'] = 29.5
albedosK13_dict['hg'] = 28.7
albedosK13_dict['ip'] = 30.7
albedosK13_dict['mi'] = 31.3
albedosK13_dict['mp'] = 30.2
albedosK13_dict['no'] = 30.8                    

#Instantaneous forcings from Zhang and Huang, 2014, Table 1
#(These are for CO2 quadrupling, not doubling)
#Not a lot of the same models--ask 
instaForcingsZH = {'ca': 5.74, 
                   'cc': 5.51, 
                   'hg': 5.55,
                   'ip': 4.51,
                   'no': 5.55}
                   
#Instantaneous forcing from Chung and Soden, 2015, ERL, Figure 2b
#(actual numbers from Chung, sent by email)
#2 methods--double call and kernel. Double call more accurate; should apply some correction for kernel for BNU. 
instaForcingsCS_DoubleCall = {'ca': 5.6, 
                              'ip': 4.4}
                              
instaForcingsCS_Kernel = {'bn': 6.4, 
                          'ca': 5.9, 
                          'hg': 6.2, 
                          'ip': 4.6, 
                          'mi': 6.0, 
                          'no': 5.7}
                          
#How much a correction to apply? Based on models where both types of estimates are available: 
#CanESM2: 5.3/5.9 = 0.898
#INM-CM4: 4.6/4.9 = 0.939
#IPSL-CM5A-LR: 4.4/4.6 = 0.957
#IPSL-CM5A-MR: 4.3/4.6 = 0.935
#MIROC5: 4.3/6.3 = 0.683

#>>> np.mean([0.898, 0.939, 0.957, 0.935, 0.683])
#0.88239999999999996

#So multiply kernel estimates by .88 where these are only ones available. 

#Best available estimates of instantaneous forcing:
instaForcings_optimal = {'bn': instaForcingsCS_Kernel['bn']*.88,
                         'ca': instaForcingsCS_DoubleCall['ca'],
                         'cc': instaForcingsZH['cc'],
                         'hg': instaForcingsZH['hg'],
                         'ip': instaForcingsCS_DoubleCall['ip'],
                         'mi': instaForcingsCS_Kernel['mi']*.88,
                         'no': instaForcingsZH['no']}

#(Note: did not end up using BNU or MIROC instantaneous forcings in the paper.)

#Stratospheric temperature adjustments in LW for quadrupling of CO2 (from Zhang and Huang, 2014) (w/m^2)
stratAdjustments_ZH = {'ca': 1.72, 
                       'cc': 1.82, 
                       'hg': 2.16, 
                       'ip': 1.55, 
                       'no': 1.76}



#Predicted solar constant reduction and residuals based on effective forcing:

#Predicted solar constant change based on formula: (delta S0) = 4*(delta RF)/(1-alpha) (W/m^2)
predictedDeltaS0_dict = dict() #This is in W m^-2. Need in percentage terms for apples to apples comparison
predictedSolarReduction_dict = dict() #This one will be in percent
for key in forcingsS14_dict.keys():
    predictedDeltaS0_dict[key] = 2*4.*forcingsS14_dict[key]/(1.-albedosK13_dict[key]/100.) #2* for quadrupling instead of doubling of CO2
    predictedSolarReduction_dict[key] = predictedDeltaS0_dict[key]/1361.*100.

print(predictedSolarReduction_dict) #debug--check units, etc. 

#Residual: actual minus predicted reduction in solar constant
#(in percent and Watts/m^2)
residuals_dict = dict()
for key in forcingsS14_dict.keys():
    residuals_dict[key] = reductions_dict[key] - predictedSolarReduction_dict[key]

    
#Convert residuals to W/m^2 (in terms of change in TOA radiation budget) (This requires taking into account the albedo)
residuals_dict_wm2 = dict()    
for key in forcingsS14_dict.keys():
    residuals_dict_wm2[key] = residuals_dict[key]/100.*1361./4.*(1.-albedosK13_dict[key]/100.)
    #Divide by 100 goes from percent to fraction
    #Multiply by 1361 goes back to W/m^2 coming down at TOA, but normal to Earth cross-section and not net after reflection of some
    #Divide by 4 for earth area
    #Multiply by 1 - albedo for absorbed fraction

print(residuals_dict)
print(residuals_dict_wm2)




#Predicted solar constant reduction and residuals based on instantaneous forcing: (same calculations as above with "_I" tag added)

#Predicted solar constant change based on formula: (delta S0) = 4*(delta RF)/(1-alpha) (W/m^2)
predictedDeltaS0_dict_I = dict() #This is in W m^-2. Need in percentage terms for apples to apples comparison
predictedSolarReduction_dict_I = dict() #This one will be in percent
for key in instaForcings_optimal.keys():
    predictedDeltaS0_dict_I[key] = 4.*instaForcings_optimal[key]/(1.-albedosK13_dict[key]/100.) #No 2* this time because forcings already for quadrupling
    predictedSolarReduction_dict_I[key] = predictedDeltaS0_dict_I[key]/1361.*100.

print(predictedSolarReduction_dict_I) #debug--check units, etc. 

#Residual: actual minus predicted reduction in solar constant
#(in percent and Watts/m^2)
residuals_dict_I = dict()
for key in instaForcings_optimal.keys():
    residuals_dict_I[key] = reductions_dict[key] - predictedSolarReduction_dict_I[key]

    
#Convert residuals to W/m^2 (in terms of change in TOA radiation budget) (This requires taking into account the albedo)
residuals_dict_wm2_I = dict()    
for key in instaForcings_optimal.keys():
    residuals_dict_wm2_I[key] = residuals_dict_I[key]/100.*1361./4.*(1.-albedosK13_dict[key]/100.)
    #Divide by 100 goes from percent to fraction
    #Multiply by 1361 goes back to W/m^2 coming down at TOA, but normal to Earth cross-section and not net after reflection of some
    #Divide by 4 for earth area
    #Multiply by 1 - albedo for absorbed fraction

print(residuals_dict_I)
print(residuals_dict_wm2_I)



#Load npy files with various global mean radiative quantities

#APRP SW cloud changes, and non-cloud atmosphere and surface albedo changes 
#Saved by script: scriptUsingAPRPonGeoMIP.py
globalMean_APRPcloud_geo_dict = np.load('npyFiles/globalMean_APRPcloud_geo.npy').item()
globalMean_APRPnoncloud_geo_dict = np.load('npyFiles/globalMean_APRPnoncloud_geo.npy').item()
globalMean_APRPsurface_geo_dict = np.load('npyFiles/globalMean_APRPsurface_geo.npy').item()

#LW changes from radiative kernels 
#Saved by "analyzeKernelResults.py"
globalMean_taKernel_G1minusPI_dict = np.load('npyFiles/shellKernels/globalMean_dLW_ta_G1minusPI.npy').item()
globalMean_tsKernel_G1minusPI_dict = np.load('npyFiles/shellKernels/globalMean_dLW_ts_G1minusPI.npy').item()
globalMean_wvKernel_G1minusPI_dict = np.load('npyFiles/shellKernels/globalMean_dLW_wv_G1minusPI.npy').item()

#Saved by "mapLWCRE.py"
globalMean_lwCloudAdjustment_G1minusPI_dict = np.load('npyFiles/globalMean_cloudLW_Adjustment_G1minusPI.npy').item()





#####   GRAPHS   #####

#First set of bar graphs, based on effective forcing

#Models for which I have all the global mean quanitites but not necessarily instantaneous forcing:
models_effective = ['bn', 'ca', 'cc', 'hg', 'ip', 'mi', 'mp', 'no']

#Calculate the quantities to go in the bars
xpos = [1,2,3,4,5,6,7,8,9]
bars_effective = dict()
for key in models_effective:
    bars_effective[key] = [residuals_dict_wm2[key], 
                          globalMean_APRPcloud_geo_dict[key] + globalMean_APRPsurface_geo_dict[key] + 
                          globalMean_APRPnoncloud_geo_dict[key] - globalMean_taKernel_G1minusPI_dict[key] - 
                          globalMean_tsKernel_G1minusPI_dict[key] -  globalMean_wvKernel_G1minusPI_dict[key] + 
                          globalMean_lwCloudAdjustment_G1minusPI_dict[key],                   
                          globalMean_APRPcloud_geo_dict[key], globalMean_APRPsurface_geo_dict[key], 
                          globalMean_APRPnoncloud_geo_dict[key], -globalMean_tsKernel_G1minusPI_dict[key],
                         -globalMean_taKernel_G1minusPI_dict[key], -globalMean_wvKernel_G1minusPI_dict[key],
                          globalMean_lwCloudAdjustment_G1minusPI_dict[key]]
                          

#Subplot version, with legend

labels = ['$F_\mathrm{excess}$ (effective)', '$\sum \Delta R_x$', 'SW cloud change', 'Surface albedo', 'SW clear-sky', 
          '$\Delta T$ (surface)', '$\Delta T$ (atmosphere)', 'Water vapor', 'LW cloud change']

(w,h) = plt.figaspect(0.95)*1.9
plt.figure(0, figsize=(w,h))
for i in range(8):
    plt.subplot(3,3,i+1)
    plt.bar(xpos, bars_effective[models_effective[i]], color = ['k', [0.5, 0.5, 0.5], 'r', 'darkred', 'coral', 'royalblue', 'deepskyblue', 'green', 'magenta'], width=1, linewidth=0)
    plt.axis([0, 11, -2, 6])
    plt.hlines(0, 0, 11, colors='k')
    if i == 0 or i == 3 or i == 6:
        plt.ylabel('W m$^{-2}$', fontsize=16)
    plt.gca().get_xaxis().set_ticks([])
    plt.gca().tick_params(axis='y', which='major', labelsize=14)
    plt.title(modelNames[models_effective[i]], fontsize=16)
plt.subplot(3,3,9) #Empty slot--put legend here
f0, = plt.plot([0.45, 0.55], [0.45, 0.55], 'k', linewidth=11)
f1, = plt.plot([0.45, 0.55], [0.45, 0.55], color=[0.5, 0.5, 0.5], linewidth=11)
f2, = plt.plot([0.45, 0.55], [0.45, 0.55], 'r', linewidth=11)
f3, = plt.plot([0.45, 0.55], [0.45, 0.55], 'darkred', linewidth=11)
f4, = plt.plot([0.45, 0.55], [0.45, 0.55], 'coral', linewidth=11)
f5, = plt.plot([0.45, 0.55], [0.45, 0.55], 'royalblue', linewidth=11)
f6, = plt.plot([0.45, 0.55], [0.45, 0.55], 'deepskyblue', linewidth=11)
f7, = plt.plot([0.45, 0.55], [0.45, 0.55], 'green', linewidth=11)
f8, = plt.plot([0.45, 0.55], [0.45, 0.55], 'magenta', linewidth=11)
plt.axis([1,2, 1,2])
plt.gca().get_xaxis().set_ticks([])
plt.gca().get_yaxis().set_ticks([])
plt.legend([f0, f1, f2, f3, f4, f5, f6, f7, f8], labels, frameon=False, fontsize=15, loc='center')
plt.tight_layout()
#plt.savefig('plots/ResidualBarGraphsEffective.pdf')
plt.savefig('plots/ResidualBarGraphsEffective_flipped.pdf')

                   
                   
                   
#Second set of bar graphs, based on instantanous forcing
                   
models_insta = ['bn', 'ca', 'cc', 'hg', 'ip', 'mi', 'no']
bars_insta = copy.deepcopy(bars_effective) #"deepcopy" necessary to avoid  reassigning bars_effective[key][0]
for key in models_insta:
    bars_insta[key][0] = residuals_dict_wm2_I[key] #replace the solar constant residual based on effective forcing with that based on instantaneous. Otherwise same

                   


labels2 = ['$F_\mathrm{excess}$ (instantaneous)',  '$\sum \Delta R_x$', 'SW cloud change', 'Surface albedo', 'SW clear-sky', 
          '$\Delta T$ (surface)', '$\Delta T$ (atmosphere)', 'Stratospheric adj.', 'Water vapor', 'LW cloud change']
#
#plt.figure(1, figsize=(w,h))
#for i in range(7):
#    if i < 6:    
#        plt.subplot(3,3,i+1)
#    else: 
#        plt.subplot(3,3,i+2) #skip spot where MPI was
#    plt.bar(xpos, bars_insta[models_insta[i]], color = ['k', 'r', 'darkred', 'coral', 'royalblue', 'deepskyblue', 'green', 'magenta', [0.5, 0.5, 0.5]], width=1, linewidth=0)
#    if models_insta[i] in stratAdjustments_ZH.keys(): #show contribution of stratospheric adjustment to 4xCO2 to the temperature bar
#        plt.bar(6, stratAdjustments_ZH[models_insta[i]], color=['navy'], width=1, linewidth=0)
#    plt.axis([0, 11, -2, 7])
#    plt.hlines(0, 0, 11, colors='k')
#    if i == 0 or i == 3 or i == 6:
#        plt.ylabel('W m$^{-2}$', fontsize=16)
#    plt.gca().get_xaxis().set_ticks([])
#    plt.gca().tick_params(axis='y', which='major', labelsize=14)
#    plt.title(modelNames[models_insta[i]], fontsize=16)
#plt.subplot(3,3,9) #Empty slot--put legend here
#f0, = plt.plot([0.45, 0.55], [0.45, 0.55], 'k', linewidth=11)
#f1, = plt.plot([0.45, 0.55], [0.45, 0.55], 'r', linewidth=11)
#f2, = plt.plot([0.45, 0.55], [0.45, 0.55], 'darkred', linewidth=11)
#f3, = plt.plot([0.45, 0.55], [0.45, 0.55], 'coral', linewidth=11)
#f4, = plt.plot([0.45, 0.55], [0.45, 0.55], 'royalblue', linewidth=11)
#f5, = plt.plot([0.45, 0.55], [0.45, 0.55], 'deepskyblue', linewidth=11)
#f55, = plt.plot([0.45, 0.55], [0.45, 0.55], 'navy', linewidth=11)
#f6, = plt.plot([0.45, 0.55], [0.45, 0.55], 'green', linewidth=11)
#f7, = plt.plot([0.45, 0.55], [0.45, 0.55], 'magenta', linewidth=11)
#f8, = plt.plot([0.45, 0.55], [0.45, 0.55], color=[0.5, 0.5, 0.5], linewidth=11)
#plt.axis([1,2, 1,2])
#plt.gca().get_xaxis().set_ticks([])
#plt.gca().get_yaxis().set_ticks([])
#plt.legend([f0, f1, f2, f3, f4, f5, f55, f6, f7, f8], labels2, frameon=False, fontsize=14, loc='center')
#plt.tight_layout()
#plt.savefig('plots/ResidualBarGraphsInstantaneous.pdf')

#Agreement not as good for BNU or MIROC, because don't know how much to reduce the estimate by--could be as much as 1/3. Could put in error bars for this...
#but probably better to skip the BNU and MIROC models. Instead do the other 5, 2x3 subplot. 

models_strat = ['ca', 'cc', 'hg', 'ip', 'no'] #Models with Zhang & Hwang estimates of inst. forcing. 
                                              #These are also the 5 models for which I have stratospheric adjustment estimates
(w2, h2) = plt.figaspect(0.65)*1.3
plt.figure(2, figsize=(w2,h2))
for i in range(5):
    plt.subplot(2,3,i+1) 
    plt.bar(xpos, bars_insta[models_strat[i]], color = ['k', [0.5, 0.5, 0.5], 'r', 'darkred', 'coral', 'royalblue', 'deepskyblue', 'green', 'magenta'], width=1, linewidth=0)
    plt.bar(7, stratAdjustments_ZH[models_strat[i]], color=['navy'], width=1, linewidth=0)
    plt.axis([0, 11, -2, 6])
    plt.hlines(0, 0, 11, colors='k')
    if i == 0 or i == 3:
        plt.ylabel('W m$^{-2}$', fontsize=16)
    plt.gca().get_xaxis().set_ticks([])
    plt.gca().tick_params(axis='y', which='major', labelsize=14)
    plt.title(modelNames[models_strat[i]], fontsize=16)
plt.subplot(2,3,6) #Empty slot--put legend here
f0, = plt.plot([0.45, 0.55], [0.45, 0.55], 'k', linewidth=11)
f1, = plt.plot([0.45, 0.55], [0.45, 0.55], color=[0.5, 0.5, 0.5], linewidth=11)
f2, = plt.plot([0.45, 0.55], [0.45, 0.55], 'r', linewidth=11)
f3, = plt.plot([0.45, 0.55], [0.45, 0.55], 'darkred', linewidth=11)
f4, = plt.plot([0.45, 0.55], [0.45, 0.55], 'coral', linewidth=11)
f5, = plt.plot([0.45, 0.55], [0.45, 0.55], 'royalblue', linewidth=11)
f6, = plt.plot([0.45, 0.55], [0.45, 0.55], 'deepskyblue', linewidth=11)
f66, = plt.plot([0.45, 0.55], [0.45, 0.55], 'navy', linewidth=11)
f7, = plt.plot([0.45, 0.55], [0.45, 0.55], 'green', linewidth=11)
f8, = plt.plot([0.45, 0.55], [0.45, 0.55], 'magenta', linewidth=11)
plt.axis([1,2, 1,2])
plt.gca().get_xaxis().set_ticks([])
plt.gca().get_yaxis().set_ticks([])
plt.legend([f0, f1, f2, f3, f4, f5, f6, f66, f7, f8], labels2, frameon=False, fontsize=14, loc='center')
plt.tight_layout()
#plt.savefig('plots/ResidualBarGraphsInstantaneous_5Models.pdf')
plt.savefig('plots/ResidualBarGraphsInstantaneous_5Models_flipped.pdf')


                   
                   
                   
#Print the values on the bar graphs, for paper table

#Effective
for i in range(len(labels)): 
    print(labels[i])
    for key in models_effective:
        print(key + ': ' + str(bars_effective[key][i]))
    print('')
    
#Instantaneous    
for i in range(len(labels)):
    print(labels[i])
    for key in models_strat:
        print(key + ': ' + str(bars_insta[key][i]))
    print('')
    
                   
#Console output    
#$F_\mathrm{excess}$ (effective)
#bn: 2.949642
#ca: 1.89505
#cc: 2.54652825
#hg: 3.56133175
#ip: 2.01276375
#mi: 3.1475875
#mp: 2.8622415
#no: 2.99812
#
#SW cloud change
#bn: 1.35916813646
#ca: 1.43895440791
#cc: 2.08838788498
#hg: 1.05438036034
#ip: 1.3244050879
#mi: 3.28577298794
#mp: 2.62501722014
#no: 2.07022868641
#
#Surface albedo
#bn: 0.506108076824
#ca: -0.0379708876622
#cc: 0.277262001711
#hg: 0.49530706195
#ip: 0.149627453549
#mi: 0.0166840213753
#mp: 0.1695297307
#no: 0.0504476497596
#
#SW clear-sky
#bn: 0.0519998402991
#ca: 0.410851268956
#cc: -0.050801576057
#hg: 1.06899230421
#ip: 1.2086178012
#mi: 0.0591918189991
#mp: -0.00246902555408
#no: -0.204370510875
#
#$\Delta T$ (surface)
#bn: 0.0848445827993
#ca: 0.0662226729352
#cc: -0.0788816480597
#hg: -0.0469967265003
#ip: -0.0468136143011
#mi: 0.0985015311451
#mp: 0.0650909254833
#no: 0.0837273990993
#
#$\Delta T$ (atmosphere)
#bn: 2.94124174338
#ca: 3.03092138742
#cc: 2.52515261947
#hg: 2.65711971584
#ip: 2.08456239855
#mi: 3.44472535814
#mp: 3.41357236522
#no: 2.88017845235
#
#Water vapor
#bn: -0.783727287427
#ca: -1.04161634348
#cc: -0.843551953362
#hg: -0.866161886349
#ip: -0.519699068553
#mi: -1.11003246626
#mp: -1.0979893454
#no: -0.96610039243
#
#LW cloud change
#bn: -0.0766409705927
#ca: -0.26355817659
#cc: 0.129266158313
#hg: -0.149072014191
#ip: -0.855072644727
#mi: -0.579599562053
#mp: -0.54325583803
#no: -0.0982464632418
#
#Sum
#bn: 4.08299412174
#ca: 3.60380432949
#cc: 4.046833487
#hg: 4.21356881531
#ip: 3.34562741362
#mi: 5.21524368929
#mp: 4.62949603256
#no: 3.81586482107
#
#$F_\mathrm{excess}$ (effective)
#ca: 3.99505
#cc: 4.43652825
#hg: 3.91133175
#ip: 3.85276375
#no: 3.86812
#
#SW cloud change
#ca: 1.43895440791
#cc: 2.08838788498
#hg: 1.05438036034
#ip: 1.3244050879
#no: 2.07022868641
#
#Surface albedo
#ca: -0.0379708876622
#cc: 0.277262001711
#hg: 0.49530706195
#ip: 0.149627453549
#no: 0.0504476497596
#
#SW clear-sky
#ca: 0.410851268956
#cc: -0.050801576057
#hg: 1.06899230421
#ip: 1.2086178012
#no: -0.204370510875
#
#$\Delta T$ (surface)
#ca: 0.0662226729352
#cc: -0.0788816480597
#hg: -0.0469967265003
#ip: -0.0468136143011
#no: 0.0837273990993
#
#$\Delta T$ (atmosphere)
#ca: 3.03092138742
#cc: 2.52515261947
#hg: 2.65711971584
#ip: 2.08456239855
#no: 2.88017845235
#
#Water vapor
#ca: -1.04161634348
#cc: -0.843551953362
#hg: -0.866161886349
#ip: -0.519699068553
#no: -0.96610039243
#
#LW cloud change
#ca: -0.26355817659
#cc: 0.129266158313
#hg: -0.149072014191
#ip: -0.855072644727
#no: -0.0982464632418
#
#Sum
#ca: 3.60380432949
#cc: 4.046833487
#hg: 4.21356881531
#ip: 3.34562741362
#no: 3.81586482107
#
#  


#Calculate total solar forcings (actual and predicted from instantaneous forcing plus sum of radaitive effects)

#Actual
print('Actual solar forcings calculation')
solarForcings_actual = dict()
for key in ['bn', 'ca', 'cc', 'ce', 'gi', 'hg', 'ip', 'mi', 'mp', 'no']:
    solarForcings_actual[key] = reductions_dict[key]*1361./100.*(1-albedosK13_dict[key]/100.)/4.
    print(key + ': ' +  str(solarForcings_actual[key]))
    
#Predicted
print('Predicted solar forcings calculation from instantaneous forcing and sum of radiative effects')                   
solarForcings_predicted = dict()
for key in ['ca', 'cc', 'hg', 'ip', 'no']:
    solarForcings_predicted[key] = instaForcings_optimal[key] + bars_insta[key][-1]
    print(key + ': ' +  str(solarForcings_predicted[key]))
                   
                   

##Console output from the above (3-8-18):
#Actual solar forcings calculation
#bn: 10.509642
#ca: 9.59505
#cc: 9.94652825
#ce: 11.258192
#gi: 10.79443125
#hg: 9.46133175
#ip: 8.25276375
#mi: 11.6875875
#mp: 11.1622415
#no: 9.41812
#Predicted solar forcings calculation from instantaneous forcing and sum of radiative effects
#ca: 9.20380432949
#cc: 9.556833487
#hg: 9.76356881531
#ip: 7.74562741362
#no: 9.36586482107


plt.show()

